@@ -14,6 +14,9 @@ import pandas as pd
 import networkx as nx
 
 
+import math
+
+
 def main():
     G_icd9, codes_icd9 = build_icd9_hierarchy_from_url(
         "https://raw.githubusercontent.com/kshedden/icd9/master/icd9/resources/icd9Hierarchy.json"
@@ -30,12 +33,17 @@ def main():
         "https://www.cms.gov/files/zip/2021-code-descriptions-tabular-order.zip",
         "https://www.cms.gov/files/zip/2021-code-tables-and-index.zip",
     )
+    G_icd10cm_2022, codes_icd10cm_2022 = build_icd10_hierarchy_from_url(
+        "https://www.cms.gov/files/zip/2022-code-descriptions-tabular-order-updated-02012022.zip",
+        "https://www.cms.gov/files/zip/2022-code-tables-tabular-and-index-updated-02012022.zip",     
+    )
     outdir = Path("icdcodex/data")
     for G, codes, fname in [
         (G_icd9, codes_icd9, "icd-9-hierarchy.json"),
         (G_icd10cm_2019, codes_icd10cm_2019, "icd-10-2019-hierarchy.json",),
         (G_icd10cm_2020, codes_icd10cm_2020, "icd-10-2020-hierarchy.json",),
         (G_icd10cm_2021, codes_icd10cm_2021, "icd-10-2021-hierarchy.json",),
+        (G_icd10cm_2022, codes_icd10cm_2022, "icd-10-2022-hierarchy.json",),
     ]:
         with open(outdir / fname, "w") as f:
             root_node, *_ = nx.topological_sort(G)
